@@ -113,9 +113,7 @@ class Session:
     ...         with GMTTempFile() as fout:
     ...             # Call the grdinfo module with the virtual file as input
     ...             # and the temp file as output.
-    ...             ses.call_module(
-    ...                 "grdinfo", "{} -C ->{}".format(fin, fout.name)
-    ...             )
+    ...             ses.call_module("grdinfo", f"{fin} -C ->{fout.name}")
     ...             # Read the contents of the temp file before it's deleted.
     ...             print(fout.read().strip())
     ...
@@ -189,9 +187,8 @@ class Session:
         if Version(version) < Version(self.required_version):
             self.destroy()
             raise GMTVersionError(
-                "Using an incompatible GMT version {}. Must be equal or newer than {}.".format(
-                    version, self.required_version
-                )
+                f"Using an incompatible GMT version {version}. "
+                f"Must be equal or newer than {self.required_version}."
             )
         return self
 
@@ -366,7 +363,7 @@ class Session:
 
         if session is None:
             raise GMTCLibError(
-                "Failed to create a GMT API session:\n{}".format(self._error_message)
+                f"Failed to create a GMT API session:\n{self._error_message}"
             )
 
         self.session_pointer = session
@@ -412,7 +409,7 @@ class Session:
         status = c_destroy_session(self.session_pointer)
         if status:
             raise GMTCLibError(
-                "Failed to destroy GMT API session:\n{}".format(self._error_message)
+                f"Failed to destroy GMT API session:\n{self._error_message}"
             )
 
         self.session_pointer = None
@@ -462,9 +459,7 @@ class Session:
 
         if status != 0:
             raise GMTCLibError(
-                "Error getting default value for '{}' (error code {}).".format(
-                    name, status
-                )
+                f"Error getting default value for '{name}' (error code {status})."
             )
 
         return value.value.decode()
@@ -503,9 +498,7 @@ class Session:
         )
         if status != 0:
             raise GMTCLibError(
-                "Module '{}' failed with status code {}:\n{}".format(
-                    module, status, self._error_message
-                )
+                f"Module '{module}' failed with status code {status}:\n{self._error_message}"
             )
 
     def create_data(self, family, geometry, mode, **kwargs):
@@ -650,20 +643,16 @@ class Session:
         nmodifiers = len(parts) - 1
         if nmodifiers > 1:
             raise GMTInvalidInput(
-                "Only one modifier is allowed in constants, {} given: '{}'".format(
-                    nmodifiers, constant
-                )
+                f"Only one modifier is allowed in constants, {nmodifiers} given: '{constant}'"
             )
         if nmodifiers > 0 and valid_modifiers is None:
             raise GMTInvalidInput(
                 "Constant modifiers not allowed since valid values were not "
-                + "given: '{}'".format(constant)
+                + f"given: '{constant}'"
             )
         if name not in valid:
             raise GMTInvalidInput(
-                "Invalid constant argument '{}'. Must be one of {}.".format(
-                    name, str(valid)
-                )
+                f"Invalid constant argument '{name}'. Must be one of {str(valid)}."
             )
         if (
             nmodifiers > 0
@@ -671,9 +660,7 @@ class Session:
             and parts[1] not in valid_modifiers
         ):
             raise GMTInvalidInput(
-                "Invalid constant modifier '{}'. Must be one of {}.".format(
-                    parts[1], str(valid_modifiers)
-                )
+                f"Invalid constant modifier '{parts[1]}'. Must be one of {str(valid_modifiers)}."
             )
         integer_value = sum(self[part] for part in parts)
         return integer_value
@@ -905,7 +892,7 @@ class Session:
             self.session_pointer, dataset, gmt_type, pad, matrix_pointer
         )
         if status != 0:
-            raise GMTCLibError("Failed to put matrix of type {}.".format(matrix.dtype))
+            raise GMTCLibError(f"Failed to put matrix of type {matrix.dtype}.")
 
     def write_data(self, family, geometry, mode, wesn, output, data):
         """
@@ -974,7 +961,7 @@ class Session:
             data,
         )
         if status != 0:
-            raise GMTCLibError("Failed to write dataset to '{}'".format(output))
+            raise GMTCLibError(f"Failed to write dataset to '{output}'")
 
     @contextmanager
     def open_virtual_file(self, family, geometry, direction, data):
@@ -1036,7 +1023,7 @@ class Session:
         ...     with lib.open_virtual_file(*vfargs) as vfile:
         ...         # Send the output to a temp file so that we can read it
         ...         with GMTTempFile() as ofile:
-        ...             args = "{} ->{}".format(vfile, ofile.name)
+        ...             args = f"{vfile} ->{ofile.name}"
         ...             lib.call_module("info", args)
         ...             print(ofile.read().strip())
         ...
@@ -1083,7 +1070,7 @@ class Session:
         finally:
             status = c_close_virtualfile(self.session_pointer, vfname.encode())
             if status != 0:
-                raise GMTCLibError("Failed to close virtual file '{}'.".format(vfname))
+                raise GMTCLibError(f"Failed to close virtual file '{vfname}'.")
 
     @contextmanager
     def virtualfile_from_vectors(self, *vectors):
@@ -1131,9 +1118,7 @@ class Session:
         ...     with ses.virtualfile_from_vectors(x, y, z) as fin:
         ...         # Send the output to a file so that we can read it
         ...         with GMTTempFile() as fout:
-        ...             ses.call_module(
-        ...                 "info", "{} ->{}".format(fin, fout.name)
-        ...             )
+        ...             ses.call_module("info", f"{fin} ->{fout.name}")
         ...             print(fout.read().strip())
         ...
         <vector memory>: N = 3 <1/3> <4/6> <7/9>
@@ -1244,9 +1229,7 @@ class Session:
         ...     with ses.virtualfile_from_matrix(data) as fin:
         ...         # Send the output to a file so that we can read it
         ...         with GMTTempFile() as fout:
-        ...             ses.call_module(
-        ...                 "info", "{} ->{}".format(fin, fout.name)
-        ...             )
+        ...             ses.call_module("info", f"{fin} ->{fout.name}")
         ...             print(fout.read().strip())
         ...
         <matrix memory>: N = 4 <0/9> <1/10> <2/11>
@@ -1327,7 +1310,7 @@ class Session:
         ...     with ses.virtualfile_from_grid(data) as fin:
         ...         # Send the output to a file so that we can read it
         ...         with GMTTempFile() as fout:
-        ...             args = "{} -L0 -Cn ->{}".format(fin, fout.name)
+        ...             args = f"{fin} -L0 -Cn ->{fout.name}"
         ...             ses.call_module("grdinfo", args)
         ...             print(fout.read().strip())
         ...
@@ -1362,7 +1345,14 @@ class Session:
 
     @fmt_docstring
     def virtualfile_from_data(
-        self, check_kind=None, data=None, x=None, y=None, z=None, extra_arrays=None
+        self,
+        check_kind=None,
+        data=None,
+        x=None,
+        y=None,
+        z=None,
+        extra_arrays=None,
+        required_z=False,
     ):
         """
         Store any data inside a virtual file.
@@ -1376,14 +1366,17 @@ class Session:
         check_kind : str
             Used to validate the type of data that can be passed in. Choose
             from 'raster', 'vector' or None. Default is None (no validation).
-        data : str or xarray.DataArray or {table-like} or None
-            Any raster or vector data format. This could be a file name, a
-            raster grid, a vector matrix/arrays, or other supported data input.
+        data : str or pathlib.Path or xarray.DataArray or {table-like} or None
+            Any raster or vector data format. This could be a file name or
+            path, a raster grid, a vector matrix/arrays, or other supported
+            data input.
         x/y/z : 1d arrays or None
             x, y and z columns as numpy arrays.
         extra_arrays : list of 1d arrays
             Optional. A list of numpy arrays in addition to x, y and z. All
             of these arrays must be of the same size as the x/y/z arrays.
+        required_z : bool
+            State whether the 'z' column is required.
 
         Returns
         -------
@@ -1414,7 +1407,7 @@ class Session:
         ...
         <vector memory>: N = 3 <7/9> <4/6> <1/3>
         """
-        kind = data_kind(data, x, y, z)
+        kind = data_kind(data, x, y, z, required_z=required_z)
 
         if check_kind == "raster" and kind not in ("file", "grid"):
             raise GMTInvalidInput(f"Unrecognized data type for grid: {type(data)}")
@@ -1439,8 +1432,11 @@ class Session:
         }[kind]
 
         # Ensure the data is an iterable (Python list or tuple)
-        if kind in ("file", "geojson", "grid"):
+        if kind in ("geojson", "grid"):
             _data = (data,)
+        elif kind == "file":
+            # Useful to handle `pathlib.Path` and string file path alike
+            _data = (str(data),)
         elif kind == "vectors":
             _data = [np.atleast_1d(x), np.atleast_1d(y)]
             if z is not None:
@@ -1497,7 +1493,7 @@ class Session:
         >>> with Session() as lib:
         ...     wesn = lib.extract_region()
         ...
-        >>> print(", ".join(["{:.2f}".format(x) for x in wesn]))
+        >>> print(", ".join([f"{x:.2f}" for x in wesn]))
         0.00, 10.00, -20.00, -10.00
 
         Using ISO country codes for the regions (for example ``'US.HI'`` for
@@ -1510,7 +1506,7 @@ class Session:
         >>> with Session() as lib:
         ...     wesn = lib.extract_region()
         ...
-        >>> print(", ".join(["{:.2f}".format(x) for x in wesn]))
+        >>> print(", ".join([f"{x:.2f}" for x in wesn]))
         -164.71, -154.81, 18.91, 23.58
 
         The country codes can have an extra argument that rounds the region a
@@ -1524,7 +1520,7 @@ class Session:
         >>> with Session() as lib:
         ...     wesn = lib.extract_region()
         ...
-        >>> print(", ".join(["{:.2f}".format(x) for x in wesn]))
+        >>> print(", ".join([f"{x:.2f}" for x in wesn]))
         -165.00, -150.00, 15.00, 25.00
         """
         c_extract_region = self.get_libgmt_func(
