@@ -167,7 +167,7 @@ def grd2cpt(grid, **kwargs):
         with file_context as infile:
             if "H" not in kwargs.keys():  # if no output is set
                 arg_str = " ".join([infile, build_arg_string(kwargs)])
-            elif "H" in kwargs.keys():  # if output is set
+            if "H" in kwargs:  # if output is set
                 outfile = kwargs.pop("H")
                 if not outfile or not isinstance(outfile, str):
                     raise GMTInvalidInput("'output' should be a proper file name.")
