@@ -22,7 +22,7 @@ from pygmt.helpers import (
     A="autolabel",
     B="frame",
     C="clearance",
-    J="projecton",
+    J="projection",
     M="margins",
     R="region",
     SC="sharex",
@@ -148,8 +148,9 @@ def subplot(self, nrows=1, ncols=1, **kwargs):
     {XY}
     """
     kwargs = self._preprocess(**kwargs)  # pylint: disable=protected-access
-    # allow for spaces in string with needing double quotes
-    kwargs["A"] = f'"{kwargs.get("A")}"' if kwargs.get("A") is not None else None
+    # allow for spaces in string without needing double quotes
+    if isinstance(kwargs.get("A"), str):
+        kwargs["A"] = f'"{kwargs.get("A")}"'
     kwargs["T"] = f'"{kwargs.get("T")}"' if kwargs.get("T") else None
 
     if nrows < 1 or ncols < 1:
