@@ -2,13 +2,9 @@
 Tests Figure.basemap.
 """
 import pytest
-from packaging.version import Version
-from pygmt import Figure, clib
+from pygmt import Figure
 from pygmt.exceptions import GMTInvalidInput
 
-with clib.Session() as _lib:
-    gmt_version = Version(_lib.info["version"])
-
 
 def test_basemap_required_args():
     """
