@@ -3,12 +3,12 @@
 Tests contour.
 """
 import os
-from itertools import product
 
 import numpy as np
+import pandas as pd
 import pytest
+import xarray as xr
 from pygmt import Figure
-from pygmt.exceptions import GMTInvalidInput
 
 TEST_DATA_DIR = os.path.join(os.path.dirname(__file__), "data")
 POINTS_DATA = os.path.join(TEST_DATA_DIR, "points.txt")
@@ -19,7 +19,7 @@ def data():
     """
     Load the point data from the test file.
     """
-    return np.loadtxt(POINTS_DATA)
+    return pd.read_table(POINTS_DATA, header=None, sep=r"\s+")
 
 
 @pytest.fixture(scope="module")
@@ -30,46 +30,6 @@ def region():
     return [10, 70, -5, 10]
 
 
-def test_contour_fail_no_data(data):
-    """
-    Should raise an exception if no data is given.
-    """
-    # Contour should raise an exception if no or not sufficient data
-    # is given
-    fig = Figure()
-    # Test all combinations where at least one data variable
-    # is not given:
-    for variable in product([None, data[:, 0]], repeat=3):
-        # Filter one valid configuration:
-        if not any(item is None for item in variable):
-            continue
-        with pytest.raises(GMTInvalidInput):
-            fig.contour(
-                x=variable[0],
-                y=variable[1],
-                z=variable[2],
-                region=region,
-                projection="X4i",
-                color="red",
-                frame="afg",
-                pen="",
-            )
-    # Should also fail if given too much data
-    with pytest.raises(GMTInvalidInput):
-        fig.contour(
-            x=data[:, 0],
-            y=data[:, 1],
-            z=data[:, 2],
-            data=data,
-            region=region,
-            projection="X10c",
-            style="c0.2c",
-            color="red",
-            frame="afg",
-            pen=True,
-        )
-
-
 @pytest.mark.mpl_image_compare
 def test_contour_vec(region):
     """
@@ -87,13 +47,19 @@ def test_contour_vec(region):
     return fig
 
 
-@pytest.mark.mpl_image_compare
-def test_contour_matrix(data, region):
+@pytest.mark.mpl_image_compare(filename="test_contour_matrix.png")
+@pytest.mark.parametrize(
+    "array_func",
+    [np.array, pd.DataFrame, xr.Dataset],
+)
+def test_contour_matrix(array_func, data, region):
     """
     Plot data.
     """
     fig = Figure()
-    fig.contour(data=data, projection="X10c", region=region, frame="ag", pen=True)
+    fig.contour(
+        data=array_func(data), projection="X10c", region=region, frame="ag", pen=True
+    )
     return fig
 
 
@@ -132,7 +98,7 @@ def test_contour_deprecate_columns_to_incols(region):
 
     with pytest.warns(expected_warning=FutureWarning) as record:
         fig.contour(
-            data=data,
+            data,
             projection="X10c",
             region=region,
             frame="a",
