@@ -2,6 +2,8 @@
 Tests for gmtinfo.
 """
 import os
+import pathlib
+import sys
 
 import numpy as np
 import numpy.testing as npt
@@ -19,7 +21,58 @@ def test_info():
     """
     Make sure info works on file name inputs.
     """
-    output = info(table=POINTS_DATA)
+    output = info(data=POINTS_DATA)
+    expected_output = (
+        f"{POINTS_DATA}: N = 20 "
+        "<11.5309/61.7074> "
+        "<-2.9289/7.8648> "
+        "<0.1412/0.9338>\n"
+    )
+    assert output == expected_output
+
+
+def test_info_deprecate_table_to_data():
+    """
+    Make sure that the old parameter "table" is supported and it reports a
+    warning.
+    """
+    with pytest.warns(expected_warning=FutureWarning) as record:
+        output = info(table=POINTS_DATA)  # pylint: disable=no-value-for-parameter
+        expected_output = (
+            f"{POINTS_DATA}: N = 20 "
+            "<11.5309/61.7074> "
+            "<-2.9289/7.8648> "
+            "<0.1412/0.9338>\n"
+        )
+        assert output == expected_output
+        assert len(record) == 1  # check that only one warning was raised
+
+
+@pytest.mark.parametrize(
+    "table",
+    [
+        pathlib.Path(POINTS_DATA),
+        pytest.param(
+            pathlib.PureWindowsPath(POINTS_DATA),
+            marks=pytest.mark.skipif(
+                sys.platform != "win32",
+                reason="PureWindowsPath is only available on Windows",
+            ),
+        ),
+        pytest.param(
+            pathlib.PurePosixPath(POINTS_DATA),
+            marks=pytest.mark.skipif(
+                sys.platform == "win32",
+                reason="PurePosixPath is not available on Windows",
+            ),
+        ),
+    ],
+)
+def test_info_path(table):
+    """
+    Make sure info works on a pathlib.Path input.
+    """
+    output = info(data=table)
     expected_output = (
         f"{POINTS_DATA}: N = 20 "
         "<11.5309/61.7074> "
@@ -33,7 +86,7 @@ def test_info_2d_list():
     """
     Make sure info works on a 2d list.
     """
-    output = info(table=[[0, 8], [3, 5], [6, 2]])
+    output = info(data=[[0, 8], [3, 5], [6, 2]])
     expected_output = "<vector memory>: N = 3 <0/6> <2/8>\n"
     assert output == expected_output
 
@@ -52,7 +105,7 @@ def test_info_dataframe():
     Make sure info works on pandas.DataFrame inputs.
     """
     table = pd.read_csv(POINTS_DATA, sep=" ", header=None)
-    output = info(table=table)
+    output = info(data=table)
     expected_output = (
         "<vector memory>: N = 20 <11.5309/61.7074> <-2.9289/7.8648> <0.1412/0.9338>\n"
     )
@@ -64,7 +117,7 @@ def test_info_numpy_array_time_column():
     Make sure info works on a numpy.ndarray input with a datetime type.
     """
     table = pd.date_range(start="2020-01-01", periods=5).to_numpy()
-    output = info(table=table)
+    output = info(data=table)
     expected_output = (
         "<vector memory>: N = 5 <2020-01-01T00:00:00/2020-01-05T00:00:00>\n"
     )
@@ -81,7 +134,7 @@ def test_info_pandas_dataframe_time_column():
             "time": pd.date_range(start="2020-01-01", periods=5),
         }
     )
-    output = info(table=table)
+    output = info(data=table)
     expected_output = (
         "<vector memory>: N = 5 <10/15> <2020-01-01T00:00:00/2020-01-05T00:00:00>\n"
     )
@@ -99,7 +152,7 @@ def test_info_xarray_dataset_time_column():
             "time": ("index", pd.date_range(start="2020-01-01", periods=5)),
         },
     )
-    output = info(table=table)
+    output = info(data=table)
     expected_output = (
         "<vector memory>: N = 5 <10/15> <2020-01-01T00:00:00/2020-01-05T00:00:00>\n"
     )
@@ -111,7 +164,7 @@ def test_info_2d_array():
     Make sure info works on 2D numpy.ndarray inputs.
     """
     table = np.loadtxt(POINTS_DATA)
-    output = info(table=table)
+    output = info(data=table)
     expected_output = (
         "<matrix memory>: N = 20 <11.5309/61.7074> <-2.9289/7.8648> <0.1412/0.9338>\n"
     )
@@ -122,7 +175,7 @@ def test_info_1d_array():
     """
     Make sure info works on 1D numpy.ndarray inputs.
     """
-    output = info(table=np.arange(20))
+    output = info(data=np.arange(20))
     expected_output = "<vector memory>: N = 20 <0/19>\n"
     assert output == expected_output
 
@@ -131,7 +184,7 @@ def test_info_per_column():
     """
     Make sure the per_column option works.
     """
-    output = info(table=POINTS_DATA, per_column=True)
+    output = info(data=POINTS_DATA, per_column=True)
     npt.assert_allclose(
         actual=output, desired=[11.5309, 61.7074, -2.9289, 7.8648, 0.1412, 0.9338]
     )
@@ -142,7 +195,7 @@ def test_info_per_column_with_time_inputs():
     Make sure the per_column option works with time inputs.
     """
     table = pd.date_range(start="2020-01-01", periods=5).to_numpy()
-    output = info(table=table, per_column=True)
+    output = info(data=table, per_column=True)
     npt.assert_equal(
         actual=output, desired=["2020-01-01T00:00:00", "2020-01-05T00:00:00"]
     )
@@ -152,7 +205,7 @@ def test_info_spacing():
     """
     Make sure the spacing option works.
     """
-    output = info(table=POINTS_DATA, spacing=0.1)
+    output = info(data=POINTS_DATA, spacing=0.1)
     npt.assert_allclose(actual=output, desired=[11.5, 61.8, -3, 7.9])
 
 
@@ -160,7 +213,7 @@ def test_info_spacing_bounding_box():
     """
     Make sure the spacing option for writing a bounding box works.
     """
-    output = info(table=POINTS_DATA, spacing="b")
+    output = info(data=POINTS_DATA, spacing="b")
     npt.assert_allclose(
         actual=output,
         desired=[
@@ -177,7 +230,7 @@ def test_info_per_column_spacing():
     """
     Make sure the per_column and spacing options work together.
     """
-    output = info(table=POINTS_DATA, per_column=True, spacing=0.1)
+    output = info(data=POINTS_DATA, per_column=True, spacing=0.1)
     npt.assert_allclose(actual=output, desired=[11.5, 61.8, -3, 7.9, 0.1412, 0.9338])
 
 
@@ -185,7 +238,7 @@ def test_info_nearest_multiple():
     """
     Make sure the nearest_multiple option works.
     """
-    output = info(table=POINTS_DATA, nearest_multiple=0.1)
+    output = info(data=POINTS_DATA, nearest_multiple=0.1)
     npt.assert_allclose(actual=output, desired=[11.5, 61.8, 0.1])
 
 
@@ -195,4 +248,4 @@ def test_info_fails():
     DataFrame, or numpy ndarray.
     """
     with pytest.raises(GMTInvalidInput):
-        info(table=xr.DataArray(21))
+        info(data=xr.DataArray(21))
