@@ -169,7 +169,7 @@ def test_meca_spec_file():
     focal_mechanism = [-127.43, 40.81, 12, -3.19, 1.16, 3.93, -1.02, -3.93, -1.02, 23]
     # writes temp file to pass to gmt
     with GMTTempFile() as temp:
-        with open(temp.name, mode="w") as temp_file:
+        with open(temp.name, mode="w", encoding="utf8") as temp_file:
             temp_file.write(" ".join([str(x) for x in focal_mechanism]))
         # supply focal mechanisms to meca as a file
         fig.meca(
