@@ -9,12 +9,17 @@ import numpy as np
 import pandas as pd
 import pytest
 import xarray as xr
-from pygmt import Figure
+from packaging.version import Version
+from pygmt import Figure, clib
 from pygmt.exceptions import GMTInvalidInput
+from pygmt.helpers import GMTTempFile
 
 TEST_DATA_DIR = os.path.join(os.path.dirname(__file__), "data")
 POINTS_DATA = os.path.join(TEST_DATA_DIR, "points.txt")
 
+with clib.Session() as _lib:
+    gmt_version = Version(_lib.info["version"])
+
 
 @pytest.fixture(scope="module")
 def data():
@@ -297,8 +302,13 @@ def test_plot_sizes_colors_transparencies():
     return fig
 
 
-@pytest.mark.mpl_image_compare
-def test_plot_matrix(data):
+@pytest.mark.mpl_image_compare(filename="test_plot_matrix.png")
+@pytest.mark.parametrize("color", ["#aaaaaa", 170])
+@pytest.mark.xfail(
+    condition=gmt_version <= Version("6.2.0"),
+    reason="Upstream bug fixed in https://github.com/GenericMappingTools/gmt/pull/5799.",
+)
+def test_plot_matrix(data, color):
     """
     Plot the data passing in a matrix and specifying columns.
     """
@@ -308,9 +318,9 @@ def test_plot_matrix(data):
         region=[10, 70, -5, 10],
         projection="M15c",
         style="cc",
-        color="#aaaaaa",
+        color=color,
         frame="a",
-        incols="0,1,2+s0.005",
+        incols="0,1,2+s0.5",
     )
     return fig
 
@@ -426,27 +436,27 @@ def test_plot_datetime():
         ["2010-06-01", "2011-06-01T12", "2012-01-01T12:34:56"], dtype="datetime64"
     )
     y = [1.0, 2.0, 3.0]
-    fig.plot(x, y, style="c0.2c", pen="1p")
+    fig.plot(x=x, y=y, style="c0.2c", pen="1p")
 
     # pandas.DatetimeIndex
     x = pd.date_range("2013", freq="YS", periods=3)
     y = [4, 5, 6]
-    fig.plot(x, y, style="t0.2c", pen="1p")
+    fig.plot(x=x, y=y, style="t0.2c", pen="1p")
 
     # xarray.DataArray
     x = xr.DataArray(data=pd.date_range(start="2015-03", freq="QS", periods=3))
     y = [7.5, 6, 4.5]
-    fig.plot(x, y, style="s0.2c", pen="1p")
+    fig.plot(x=x, y=y, style="s0.2c", pen="1p")
 
     # raw datetime strings
     x = ["2016-02-01", "2017-03-04T00:00"]
     y = [7, 8]
-    fig.plot(x, y, style="a0.2c", pen="1p")
+    fig.plot(x=x, y=y, style="a0.2c", pen="1p")
 
     # the Python built-in datetime and date
     x = [datetime.date(2018, 1, 1), datetime.datetime(2019, 1, 1)]
     y = [8.5, 9.5]
-    fig.plot(x, y, style="i0.2c", pen="1p")
+    fig.plot(x=x, y=y, style="i0.2c", pen="1p")
     return fig
 
 
@@ -495,3 +505,46 @@ def test_plot_deprecate_columns_to_incols(region):
         )
         assert len(record) == 1  # check that only one warning was raised
     return fig
+
+
+@pytest.mark.mpl_image_compare
+def test_plot_ogrgmt_file_multipoint_default_style():
+    """
+    Make sure that OGR/GMT files with MultiPoint geometry are plotted as
+    squares and not as line (default GMT style).
+    """
+    with GMTTempFile(suffix=".gmt") as tmpfile:
+        gmt_file = """# @VGMT1.0 @GMULTIPOINT
+# @R1/1/1/1UB
+# FEATURE_DATA
+1 2
+        """
+        with open(tmpfile.name, "w", encoding="utf8") as file:
+            file.write(gmt_file)
+        fig = Figure()
+        fig.plot(data=tmpfile.name, region=[0, 2, 1, 3], projection="X2c", frame=True)
+        return fig
+
+
+@pytest.mark.mpl_image_compare
+def test_plot_ogrgmt_file_multipoint_non_default_style():
+    """
+    Make sure that non-default style can be set for plotting OGR/GMT file.
+    """
+    with GMTTempFile(suffix=".gmt") as tmpfile:
+        gmt_file = """# @VGMT1.0 @GPOINT
+# @R1/1/1/1UB
+# FEATURE_DATA
+1 2
+        """
+        with open(tmpfile.name, "w", encoding="utf8") as file:
+            file.write(gmt_file)
+        fig = Figure()
+        fig.plot(
+            data=tmpfile.name,
+            region=[0, 2, 1, 3],
+            projection="X2c",
+            frame=True,
+            style="c0.2c",
+        )
+        return fig
