@@ -8,6 +8,7 @@ import numpy as np
 import pytest
 from pygmt import Figure
 from pygmt.exceptions import GMTInvalidInput
+from pygmt.helpers import GMTTempFile
 
 TEST_DATA_DIR = os.path.join(os.path.dirname(__file__), "data")
 POINTS_DATA = os.path.join(TEST_DATA_DIR, "points.txt")
@@ -67,48 +68,6 @@ def test_plot3d_red_circles_zsize(data, region):
     return fig
 
 
-def test_plot3d_fail_no_data(data, region):
-    """
-    Plot should raise an exception if no data is given.
-    """
-    fig = Figure()
-    with pytest.raises(GMTInvalidInput):
-        fig.plot3d(
-            region=region, projection="X10c", style="c0.2c", color="red", frame="afg"
-        )
-    with pytest.raises(GMTInvalidInput):
-        fig.plot3d(
-            x=data[:, 0],
-            region=region,
-            projection="X10c",
-            style="c0.2c",
-            color="red",
-            frame="afg",
-        )
-    with pytest.raises(GMTInvalidInput):
-        fig.plot3d(
-            y=data[:, 0],
-            region=region,
-            projection="X10c",
-            style="c0.2c",
-            color="red",
-            frame="afg",
-        )
-    # Should also fail if given too much data
-    with pytest.raises(GMTInvalidInput):
-        fig.plot3d(
-            x=data[:, 0],
-            y=data[:, 1],
-            z=data[:, 2],
-            data=data,
-            region=region,
-            projection="X10c",
-            style="c0.2c",
-            color="red",
-            frame="afg",
-        )
-
-
 def test_plot3d_fail_1d_array_with_data(data, region):
     """
     Should raise an exception if array color, size, intensity and transparency
@@ -354,19 +313,21 @@ def test_plot3d_sizes_colors_transparencies():
 
 
 @pytest.mark.mpl_image_compare
-def test_plot3d_matrix(data, region):
+@pytest.mark.mpl_image_compare(filename="test_plot3d_matrix.png")
+@pytest.mark.parametrize("color", ["#aaaaaa", 170])
+def test_plot3d_matrix(data, region, color):
     """
     Plot the data passing in a matrix and specifying incols.
     """
     fig = Figure()
     fig.plot3d(
-        data=data,
+        data,
         zscale=5,
         perspective=[225, 30],
         region=region,
         projection="M20c",
         style="c1c",
-        color="#aaaaaa",
+        color=color,
         frame=["a", "za"],
         incols="0,1,2",
     )
@@ -384,7 +345,7 @@ def test_plot3d_matrix_color(data, region):
     """
     fig = Figure()
     fig.plot3d(
-        data=data,
+        data,
         zscale=5,
         perspective=[225, 30],
         region=region,
@@ -505,7 +466,7 @@ def test_plot3d_deprecate_columns_to_incols(data, region):
     fig = Figure()
     with pytest.warns(expected_warning=FutureWarning) as record:
         fig.plot3d(
-            data=data,
+            data,
             zscale=5,
             perspective=[225, 30],
             region=region,
@@ -517,3 +478,57 @@ def test_plot3d_deprecate_columns_to_incols(data, region):
         )
         assert len(record) == 1  # check that only one warning was raised
     return fig
+
+
+@pytest.mark.mpl_image_compare
+def test_plot3d_ogrgmt_file_multipoint_default_style():
+    """
+    Make sure that OGR/GMT files with MultiPoint geometry are plotted as cubes
+    and not as line (default GMT style).
+    """
+    with GMTTempFile(suffix=".gmt") as tmpfile:
+        gmt_file = """# @VGMT1.0 @GMULTIPOINT
+# @R1/1.5/1/1.5
+# FEATURE_DATA
+>
+1 1 2
+1.5 1.5 1"""
+        with open(tmpfile.name, "w", encoding="utf8") as file:
+            file.write(gmt_file)
+        fig = Figure()
+        fig.plot3d(
+            data=tmpfile.name,
+            perspective=[315, 25],
+            region=[0, 2, 0, 2, 0, 2],
+            projection="X2c",
+            frame=["WsNeZ1", "xag", "yag", "zag"],
+            zscale=1.5,
+        )
+        return fig
+
+
+@pytest.mark.mpl_image_compare
+def test_plot3d_ogrgmt_file_multipoint_non_default_style():
+    """
+    Make sure that non-default style can be set for plotting OGR/GMT file.
+    """
+    with GMTTempFile(suffix=".gmt") as tmpfile:
+        gmt_file = """# @VGMT1.0 @GMULTIPOINT
+# @R1/1.5/1/1.5
+# FEATURE_DATA
+>
+1 1 2
+1.5 1.5 1"""
+        with open(tmpfile.name, "w", encoding="utf8") as file:
+            file.write(gmt_file)
+        fig = Figure()
+        fig.plot3d(
+            data=tmpfile.name,
+            perspective=[315, 25],
+            region=[0, 2, 0, 2, 0, 2],
+            projection="X2c",
+            frame=["WsNeZ1", "xag", "yag", "zag"],
+            zscale=1.5,
+            style="c0.2c",
+        )
+        return fig
